@@ -1,9 +1,10 @@
 import datetime
-from unittest import TestCase
+from unittest import TestCase, mock
 
 import pandas as pd
 import testing.postgresql
-from mock import Mock
+from unittest.mock import Mock
+
 from triage import create_engine
 from contextlib import contextmanager
 
@@ -246,7 +247,7 @@ def get_matrix_storage_engine():
 
 
 def test_query_to_df():
-    """ Test the write_to_csv function by checking whether the csv contains the
+    """Test the write_to_csv function by checking whether the csv contains the
     correct number of lines.
     """
     with testing.postgresql.Postgresql() as postgresql:
@@ -278,7 +279,7 @@ def test_query_to_df():
 
 
 def test_make_entity_date_table():
-    """ Test that the make_entity_date_table function contains the correct
+    """Test that the make_entity_date_table function contains the correct
     values.
     """
     dates = [
@@ -336,7 +337,7 @@ def test_make_entity_date_table():
 
 
 def test_make_entity_date_table_include_missing_labels():
-    """ Test that the make_entity_date_table function contains the correct
+    """Test that the make_entity_date_table function contains the correct
     values.
     """
     dates = [
@@ -422,11 +423,11 @@ def test_load_features_data():
         cols = ["entity_id", "as_of_date"] + features[i]
         temp_df = pd.DataFrame(table, columns=cols)
         temp_df["as_of_date"] = convert_string_column_to_date(temp_df["as_of_date"])
-        features_dfs.append(
-            ids_dates.merge(
-                right=temp_df, how="left", on=["entity_id", "as_of_date"]
-            ).set_index(["entity_id", "as_of_date"])
+        merged_df = ids_dates.merge(
+            right=temp_df, how="left", on=["entity_id", "as_of_date"]
         )
+        merged_df["as_of_date"] = pd.to_datetime(merged_df["as_of_date"])
+        features_dfs.append(merged_df.set_index(["entity_id", "as_of_date"]))
 
     # create an engine and generate a table with fake feature data
     with testing.postgresql.Postgresql() as postgresql:
@@ -473,7 +474,7 @@ def test_load_features_data():
 
 
 def test_load_labels_data():
-    """ Test the load_labels_data function by checking whether the query
+    """Test the load_labels_data function by checking whether the query
     produces the correct labels
     """
     # set up labeling config variables
@@ -538,7 +539,7 @@ def test_load_labels_data():
 
 
 def test_load_labels_data_include_missing_labels_as_false():
-    """ Test the load_labels_data function by checking whether the query
+    """Test the load_labels_data function by checking whether the query
     produces the correct labels
     """
     # set up labeling config variables
@@ -705,7 +706,10 @@ class TestBuildMatrix(TestCase):
                     matrix_type="train",
                 )
                 assert len(matrix_storage_engine.get_store(uuid).design_matrix) == 5
-                assert builder.sessionmaker().query(Matrix).get(uuid).feature_dictionary ==self.good_feature_dictionary
+                assert (
+                    builder.sessionmaker().query(Matrix).get(uuid).feature_dictionary
+                    == self.good_feature_dictionary
+                )
 
     def test_test_matrix(self):
         with testing.postgresql.Postgresql() as postgresql:
@@ -853,7 +857,7 @@ class TestBuildMatrix(TestCase):
 
                 assert len(matrix_storage_engine.get_store(uuid).design_matrix) == 5
                 # rerun
-                builder.make_entity_date_table = Mock()
+                builder.make_entity_date_table = mock.Mock()
                 builder.build_matrix(
                     as_of_times=dates,
                     label_name="booking",
