@@ -5,6 +5,8 @@ import pytest
 
 from triage.component.catwalk.model_grouping import ModelGrouper
 from triage.component.catwalk.model_trainers import ModelTrainer
+from triage.component.catwalk.utils import save_experiment_and_get_hash
+from triage.tracking import initialize_tracking_and_get_run_id
 from tests.utils import get_matrix_store
 
 
@@ -22,11 +24,24 @@ def grid_config():
 @pytest.fixture(scope="function")
 def default_model_trainer(db_engine_with_results_schema, project_storage):
     model_storage_engine = project_storage.model_storage_engine()
+    experiment_hash = save_experiment_and_get_hash(
+        config={'foo': 'bar'}, 
+        db_engine=db_engine_with_results_schema
+        )
+    run_id = initialize_tracking_and_get_run_id(
+        experiment_hash,
+        experiment_class_path="",
+        random_seed=5,
+        experiment_kwargs={},
+        db_engine=db_engine_with_results_schema
+    )
+    # import pdb; pdb.set_trace()
     trainer = ModelTrainer(
-        experiment_hash=None,
+        experiment_hash=experiment_hash,
         model_storage_engine=model_storage_engine,
         db_engine=db_engine_with_results_schema,
         model_grouper=ModelGrouper(),
+        run_id=run_id,
     )
     yield trainer
 
@@ -45,7 +60,6 @@ def test_model_trainer(grid_config, default_model_trainer):
         misc_db_parameters=dict(),
         matrix_store=get_matrix_store(project_storage),
     )
-
     # assert
     # 1. that the models and feature importances table entries are present
     records = [
@@ -132,14 +146,26 @@ def test_model_trainer(grid_config, default_model_trainer):
             "select max(batch_run_time) from triage_metadata.models"
         )
     ][0]
+    experiment_hash = save_experiment_and_get_hash(
+        config={'foo': 'bar'}, 
+        db_engine=db_engine
+        )
+    run_id = initialize_tracking_and_get_run_id(
+        experiment_hash,
+        experiment_class_path="",
+        random_seed=5,
+        experiment_kwargs={},
+        db_engine=db_engine
+    )
     trainer = ModelTrainer(
-        experiment_hash=None,
+        experiment_hash=experiment_hash,
         model_storage_engine=model_storage_engine,
         model_grouper=ModelGrouper(
             model_group_keys=["label_name", "label_timespan"]
         ),
         db_engine=db_engine,
         replace=True,
+        run_id=run_id,
     )
     set_test_seed()
     new_model_ids = trainer.train_models(
@@ -212,11 +238,23 @@ def test_baseline_exception_handling(default_model_trainer):
 
 def test_custom_groups(grid_config, db_engine_with_results_schema, project_storage):
     model_storage_engine = project_storage.model_storage_engine()
+    experiment_hash = save_experiment_and_get_hash(
+        config={'foo': 'bar'}, 
+        db_engine=db_engine_with_results_schema
+        )
+    run_id = initialize_tracking_and_get_run_id(
+        experiment_hash,
+        experiment_class_path="",
+        random_seed=5,
+        experiment_kwargs={},
+        db_engine=db_engine_with_results_schema
+    )
     trainer = ModelTrainer(
-        experiment_hash=None,
+        experiment_hash=experiment_hash,
         model_storage_engine=model_storage_engine,
         model_grouper=ModelGrouper(["class_path"]),
         db_engine=db_engine_with_results_schema,
+        run_id=run_id,
     )
     # create training set
     model_ids = trainer.train_models(
@@ -235,6 +273,108 @@ def test_custom_groups(grid_config, db_engine_with_results_schema, project_stora
     assert records[0] == model_ids[0]
 
 
+def test_reuse_model_random_seeds(grid_config, default_model_trainer):
+    trainer = default_model_trainer
+    db_engine = trainer.db_engine
+    project_storage = trainer.model_storage_engine.project_storage
+    model_storage_engine = trainer.model_storage_engine
+
+    # re-using the random seeds requires the association between experiments and models
+    # to exist, which we're not getting in these tests since we aren't using the experiment
+    # architecture, so back-fill these associations after each train_models() run
+    def update_experiment_models(db_engine):
+        sql = """
+            INSERT INTO triage_metadata.experiment_models(experiment_hash,model_hash) 
+            SELECT er.run_hash, m.model_hash
+            FROM triage_metadata.models m
+            LEFT JOIN triage_metadata.triage_runs er
+                ON m.built_in_triage_run = er.id
+            LEFT JOIN triage_metadata.experiment_models em 
+                ON m.model_hash = em.model_hash
+                AND er.run_hash = em.experiment_hash
+            WHERE em.experiment_hash IS NULL
+            """
+        db_engine.execute(sql)
+        db_engine.execute('COMMIT;')
+
+    random.seed(5)
+    model_ids = trainer.train_models(
+        grid_config=grid_config,
+        misc_db_parameters=dict(),
+        matrix_store=get_matrix_store(project_storage),
+    )
+    update_experiment_models(db_engine)
+
+    # simulate running a new experiment where the experiment hash has changed
+    # (e.g. because the model grid is different), but experiment seed is the
+    # same, so previously-trained models should not get new seeds
+    experiment_hash = save_experiment_and_get_hash(
+        config={'baz': 'qux'}, 
+        db_engine=db_engine
+        )
+    run_id = initialize_tracking_and_get_run_id(
+        experiment_hash,
+        experiment_class_path="",
+        random_seed=5,
+        experiment_kwargs={},
+        db_engine=db_engine
+    )
+    trainer = ModelTrainer(
+        experiment_hash=experiment_hash,
+        model_storage_engine=model_storage_engine,
+        db_engine=db_engine,
+        model_grouper=ModelGrouper(),
+        run_id=run_id,
+    )
+    new_grid = grid_config.copy()
+    new_grid['sklearn.tree.DecisionTreeClassifier']['min_samples_split'] = [3,10,100]
+    random.seed(5)
+    new_model_ids = trainer.train_models(
+        grid_config=new_grid,
+        misc_db_parameters=dict(),
+        matrix_store=get_matrix_store(project_storage),
+    )
+    update_experiment_models(db_engine)
+
+    # should have received 5 models
+    assert len(new_model_ids) == 6
+
+    # all the original model ids should be in the new set
+    assert len(set(new_model_ids) & set(model_ids)) == len(model_ids)
+
+    # however, we should NOT re-use the random seeds (and so get new model_ids)
+    # if the experiment-level seed is different
+    experiment_hash = save_experiment_and_get_hash(
+        config={'lorem': 'ipsum'}, 
+        db_engine=db_engine
+        )
+    run_id = initialize_tracking_and_get_run_id(
+        experiment_hash,
+        experiment_class_path="",
+        random_seed=42,
+        experiment_kwargs={},
+        db_engine=db_engine
+    )
+    trainer = ModelTrainer(
+        experiment_hash=experiment_hash,
+        model_storage_engine=model_storage_engine,
+        db_engine=db_engine,
+        model_grouper=ModelGrouper(),
+        run_id=run_id,
+    )
+    random.seed(42) # different from above
+    newer_model_ids = trainer.train_models(
+        grid_config=new_grid,
+        misc_db_parameters=dict(),
+        matrix_store=get_matrix_store(project_storage),
+    )
+    update_experiment_models(db_engine)
+
+    # should get entirely new models now (different IDs)
+    assert len(newer_model_ids) == 6
+    assert len(set(new_model_ids) & set(newer_model_ids)) == 0
+
+
 def test_n_jobs_not_new_model(default_model_trainer):
     grid_config = {
         "sklearn.ensemble.AdaBoostClassifier": {"n_estimators": [10, 100, 1000]},
