@@ -1,6 +1,7 @@
 import datetime
 import functools
 import importlib
+import os
 import random
 import tempfile
 from contextlib import contextmanager
@@ -28,6 +29,43 @@ matplotlib.use("Agg")
 from matplotlib import pyplot as plt  # noqa
 
 
+CONFIG_QUERY_DATA = {
+    "cohort": {
+        "query": """
+            select distinct(entity_id)
+            from events
+            where '{as_of_date}'::date >= outcome_date
+        """,
+        "filepath": "cohorts/file.sql",
+    },
+    "label": {
+        "query": """
+            select
+                events.entity_id,
+                bool_or(outcome::bool)::integer as outcome
+            from events
+            where '{as_of_date}'::date <= outcome_date
+                and outcome_date < '{as_of_date}'::date + interval '{label_timespan}'
+            group by entity_id
+        """,
+        "filepath": "labels/file.sql",
+    },
+}
+
+MOCK_FILES = {
+    os.path.join(
+        os.path.abspath(os.getcwd()), f"{CONFIG_QUERY_DATA['label']['filepath']}"
+    ): CONFIG_QUERY_DATA["label"]["query"],
+    os.path.join(
+        os.path.abspath(os.getcwd()), f"{CONFIG_QUERY_DATA['cohort']['filepath']}"
+    ): CONFIG_QUERY_DATA["cohort"]["query"],
+}
+
+
+def open_side_effect(name):
+    return mock.mock_open(read_data=MOCK_FILES[name]).return_value
+
+
 def fake_labels(length):
     return np.array([random.choice([True, False]) for i in range(0, length)])
 
@@ -78,7 +116,7 @@ class MockMatrixStore(MatrixStore):
         self.matrix_label_tuple = matrix, labels
         self.metadata = base_metadata
         self.label_count = label_count
-        self.init_labels = pd.Series(init_labels, dtype='float64')
+        self.init_labels = pd.Series(init_labels, dtype="float64")
         self.matrix_uuid = matrix_uuid
         self.init_as_of_dates = init_as_of_dates or []
 
@@ -100,9 +138,7 @@ class MockMatrixStore(MatrixStore):
 
 
 def fake_trained_model(
-    db_engine,
-    train_matrix_uuid="efgh",
-    train_end_time=datetime.datetime(2016, 1, 1)
+    db_engine, train_matrix_uuid="efgh", train_end_time=datetime.datetime(2016, 1, 1)
 ):
     """Creates and stores a trivial trained model and training matrix
 
@@ -189,8 +225,9 @@ def get_matrix_store(project_storage, matrix=None, metadata=None, write_to_db=Tr
         metadata = matrix_metadata_creator()
     matrix["as_of_date"] = matrix["as_of_date"].apply(pd.Timestamp)
     matrix.set_index(MatrixStore.indices, inplace=True)
-    matrix_store = (project_storage.matrix_storage_engine()
-                    .get_store(filename_friendly_hash(metadata)))
+    matrix_store = project_storage.matrix_storage_engine().get_store(
+        filename_friendly_hash(metadata)
+    )
     matrix_store.metadata = metadata
     new_matrix = matrix.copy()
     labels = new_matrix.pop(matrix_store.label_column_name)
@@ -199,8 +236,9 @@ def get_matrix_store(project_storage, matrix=None, metadata=None, write_to_db=Tr
     matrix_store.clear_cache()
     if write_to_db:
         if (
-            session.query(Matrix).filter(
-                Matrix.matrix_uuid == matrix_store.uuid).count()
+            session.query(Matrix)
+            .filter(Matrix.matrix_uuid == matrix_store.uuid)
+            .count()
             == 0
         ):
             MatrixFactory(matrix_uuid=matrix_store.uuid)
@@ -299,10 +337,12 @@ def populate_source_data(db_engine):
     )
 
     db_engine.execute(
-        "create table zip_code_demographics (zip_code text, ethnicity text, as_of_date date)")
+        "create table zip_code_demographics (zip_code text, ethnicity text, as_of_date date)"
+    )
     for demographic_row in zip_code_demographics:
         db_engine.execute(
-            "insert into zip_code_demographics values (%s, %s, %s)", demographic_row)
+            "insert into zip_code_demographics values (%s, %s, %s)", demographic_row
+        )
 
     for entity_zip_code in entity_zip_codes:
         db_engine.execute(
@@ -322,8 +362,7 @@ def populate_source_data(db_engine):
         )
 
     for complaint in complaints:
-        db_engine.execute(
-            "insert into cat_complaints values (%s, %s, %s)", complaint)
+        db_engine.execute("insert into cat_complaints values (%s, %s, %s)", complaint)
 
     db_engine.execute(
         """create table events (
@@ -337,7 +376,14 @@ def populate_source_data(db_engine):
         db_engine.execute("insert into events values (%s, %s, %s)", event)
 
 
-def sample_config():
+def sample_cohort_config(query_source="filepath"):
+    return {
+        "name": "has_past_events",
+        query_source: CONFIG_QUERY_DATA["cohort"][query_source],
+    }
+
+
+def sample_config(query_source="filepath"):
     temporal_config = {
         "feature_start_time": "2010-01-01",
         "feature_end_time": "2014-01-01",
@@ -369,7 +415,7 @@ def sample_config():
                     and outcome_date < '{as_of_date}'::date
                 """,
             },
-        ]
+        ],
     }
 
     grid_config = {
@@ -388,7 +434,6 @@ def sample_config():
             "aggregates_imputation": {"all": {"type": "constant", "value": 0}},
             "aggregates": [{"quantity": "cat_sightings", "metrics": ["count", "avg"]}],
             "intervals": ["1year"],
-            "groups": ["entity_id"],
         },
         {
             "prefix": "zip_code_features",
@@ -397,40 +442,25 @@ def sample_config():
             "aggregates_imputation": {"all": {"type": "constant", "value": 0}},
             "aggregates": [{"quantity": "num_events", "metrics": ["max", "min"]}],
             "intervals": ["1year"],
-            "groups": ["entity_id", "zip_code"],
         },
     ]
 
-    cohort_config = {
-        "query": "select distinct(entity_id) from events "
-                 "where '{as_of_date}'::date >= outcome_date",
-        "name": "has_past_events",
-    }
+    cohort_config = sample_cohort_config(query_source)
 
     label_config = {
-        "query": """
-            select
-            events.entity_id,
-            bool_or(outcome::bool)::integer as outcome
-            from events
-            where '{as_of_date}'::date <= outcome_date
-                and outcome_date < '{as_of_date}'::date + interval '{label_timespan}'
-                group by entity_id
-        """,
+        query_source: CONFIG_QUERY_DATA["label"][query_source],
         "name": "custom_label_name",
         "include_missing_labels_in_train_as": False,
     }
+
     bias_audit_config = {
-        'from_obj_query': 'select * from zip_code_demographics join entity_zip_codes using (zip_code)',
-        'attribute_columns': ['ethnicity'],
-        'knowledge_date_column': 'as_of_date',
-        'entity_id_column': 'entity_id',
-        'ref_groups_method': 'predefined',
-        'ref_groups': {'ethnicity': 'white'},
-        'thresholds': {
-            'percentiles': [],
-            'top_n': [2]
-        }
+        "from_obj_query": "select * from zip_code_demographics join entity_zip_codes using (zip_code)",
+        "attribute_columns": ["ethnicity"],
+        "knowledge_date_column": "as_of_date",
+        "entity_id_column": "entity_id",
+        "ref_groups_method": "predefined",
+        "ref_groups": {"ethnicity": "white"},
+        "thresholds": {"percentiles": [], "top_n": [2]},
     }
 
     return {
@@ -439,7 +469,13 @@ def sample_config():
         "label_config": label_config,
         "entity_column_name": "entity_id",
         "model_comment": "test2-final-final",
-        "model_group_keys": ["label_name", "label_type", "custom_key"],
+        "model_group_keys": [
+            "label_name",
+            "label_type",
+            "custom_key",
+            "class_path",
+            "parameters",
+        ],
         "feature_aggregations": feature_config,
         "cohort_config": cohort_config,
         "temporal_config": temporal_config,
@@ -484,7 +520,7 @@ class CallSpy:
 
     @cachedproperty
     def target_path(self):
-        return self.signature.split('.')
+        return self.signature.split(".")
 
     @cachedproperty
     def target_name(self):
@@ -494,8 +530,8 @@ class CallSpy:
     def target_base(self):
         # walk target path until can no longer import it as a module path
         for index in range(len(self.target_path)):
-            path_parts = self.target_path[:(index + 1)]
-            import_path = '.'.join(path_parts)
+            path_parts = self.target_path[: (index + 1)]
+            import_path = ".".join(path_parts)
 
             try:
                 base = importlib.import_module(import_path)
@@ -522,8 +558,7 @@ class CallSpy:
         if not callable(self.target_object):
             # 1. ensure target_object set before patching
             # 2. check that it's sane (needn't be done here but reasonable)
-            raise TypeError(
-                f"signature target not callable {self.target_object!r}")
+            raise TypeError(f"signature target not callable {self.target_object!r}")
 
         self.patch.start()
 
