@@ -1,4 +1,5 @@
-import logging
+import verboselogs, logging
+logger = verboselogs.VerboseLogger(__name__)
 
 from triage.component.catwalk.utils import save_db_objects
 from triage.component.results_schema import IndividualImportance
@@ -11,18 +12,18 @@ CALCULATE_STRATEGIES = {"uniform": uniform_distribution}
 
 class IndividualImportanceCalculatorNoOp:
     def calculate_and_save_all_methods_and_dates(self, model_id, test_matrix_store):
-        logging.warning(
+        logger.notice(
             "No individual feature importance configuration is available, so no individual feature importance will be created"
         )
 
     def calculate_and_save(self, model_id, test_matrix_store, method, as_of_date):
-        logging.warning(
+        logger.notice(
             "No individual feature importance configuration is available, so no individual feature importance will be created"
         )
 
 
     def save(self, importance_records, model_id, as_of_date, method_name):
-        logging.warning(
+        logger.notice(
             "No individual feature importance configuration is available, so no individual feature importance will be created"
         )
 
@@ -78,14 +79,14 @@ class IndividualImportanceCalculator:
             model_id, as_of_date, method
         )
         expected_importances = matrix_store.num_entities * self.n_ranks
-        logging.debug(
+        logger.debug(
             "model_id=%s/as_of_date=%s/method=%s: found %s importances",
             model_id,
             as_of_date,
             method,
             existing_importances,
         )
-        logging.debug(
+        logger.debug(
             "matrix_uuid=%s/n_ranks=%s: expect %s importances",
             matrix_store.uuid,
             self.n_ranks,
@@ -117,7 +118,7 @@ class IndividualImportanceCalculator:
         if not self.replace and not self._needs_new_importances(
             model_id, as_of_date, method, test_matrix_store
         ):
-            logging.info(
+            logger.debug(
                 "Found as many or more individual importances "
                 + "for model_id=%s/as_of_date=%s/method=%s, skipping",
                 model_id,
