@@ -13,6 +13,7 @@ import numpy as np
 import pandas as pd
 
 from sklearn.model_selection import ParameterGrid
+from sklearn.utils import parallel_backend
 from sqlalchemy.orm import sessionmaker
 
 from triage.util.random import generate_python_random_seed
@@ -27,6 +28,8 @@ from .utils import (
     retrieve_model_id_from_hash,
     db_retry,
     save_db_objects,
+    retrieve_existing_model_random_seeds,
+    retrieve_experiment_seed_from_run_id,
 )
 
 NO_FEATURE_IMPORTANCE = (
@@ -71,6 +74,7 @@ class ModelTrainer:
         self.db_engine = db_engine
         self.replace = replace
         self.run_id = run_id
+        self.experiment_random_seed = retrieve_experiment_seed_from_run_id(self.db_engine, self.run_id)
 
     @property
     def sessionmaker(self):
@@ -86,6 +90,7 @@ class ModelTrainer:
         same attributes there would be no reason to keep the old one)
 
         Args:
+        matrix_metadata (dict): metadata associated with training matrix for this model
         class_path (string): a full class path for the classifier
         parameters (dict): all hyperparameters to be passed to the classifier
         random_seed (int) an integer suitable for seeding the random generator before training
@@ -96,7 +101,6 @@ class ModelTrainer:
         unique = {
             "className": class_path,
             "parameters": self.unique_parameters(parameters),
-            "project_path": self.model_storage_engine.project_storage.project_path,
             "training_metadata": matrix_metadata,
             "random_seed": random_seed,
         }
@@ -119,7 +123,12 @@ class ModelTrainer:
         cls = getattr(module, class_name)
         instance = cls(**parameters)
 
-        return instance.fit(matrix_store.design_matrix, matrix_store.labels)
+        # using a threading backend because the default loky backend doesn't
+        # allow for nested parallelization (e.g., multiprocessing at triage level)
+        with parallel_backend('threading'):
+            fitted = instance.fit(matrix_store.design_matrix, matrix_store.labels)
+
+        return fitted
 
     @db_retry
     def _save_feature_importances(self, model_id, feature_importances, feature_names):
@@ -184,6 +193,7 @@ class ModelTrainer:
         model_group_id,
         model_size,
         misc_db_parameters,
+        retrain,
     ):
         """Writes model and feature importance data to a database
         Will overwrite the data of any previous versions
@@ -207,22 +217,36 @@ class ModelTrainer:
             misc_db_parameters (dict) params to pass through to the database
         """
         model_id = retrieve_model_id_from_hash(self.db_engine, model_hash)
-        if model_id and not self.replace:
+        if model_id and not self.replace and not retrain:
             logger.notice(
                 f"Metadata for model {model_id} found in database. Reusing model metadata."
             )
             return model_id
         else:
-            model = Model(
-                model_hash=model_hash,
-                model_type=class_path,
-                hyperparameters=parameters,
-                model_group_id=model_group_id,
-                built_by_experiment=self.experiment_hash,
-                built_in_experiment_run=self.run_id,
-                model_size=model_size,
-                **misc_db_parameters,
-            )
+            if retrain:
+                logger.debug("Retrain model...")
+                model = Model(
+                    model_group_id=model_group_id,
+                    model_hash=model_hash,
+                    model_type=class_path,
+                    hyperparameters=parameters,
+                    # built_by_retrain=self.experiment_hash,
+                    built_in_triage_run=self.run_id,
+                    model_size=model_size,
+                    **misc_db_parameters,
+                )
+
+            else:
+                model = Model(
+                    model_hash=model_hash,
+                    model_type=class_path,
+                    hyperparameters=parameters,
+                    model_group_id=model_group_id,
+                    # built_by_experiment=self.experiment_hash,
+                    built_in_triage_run=self.run_id,
+                    model_size=model_size,
+                    **misc_db_parameters,
+                )    
             session = self.sessionmaker()
             if model_id:
                 logger.notice(
@@ -237,7 +261,7 @@ class ModelTrainer:
                 model_id = model.model_id
                 logger.notice(f"Model {model_id}, not found from previous runs. Adding the new model")
             session.close()
-
+        
         logger.spam(f"Saving feature importances for model_id {model_id}")
         self._save_feature_importances(
             model_id, get_feature_importances(trained_model), feature_names
@@ -246,7 +270,7 @@ class ModelTrainer:
         return model_id
 
     def _train_and_store_model(
-        self, matrix_store, class_path, parameters, model_hash, misc_db_parameters, random_seed
+        self, matrix_store, class_path, parameters, model_hash, misc_db_parameters, random_seed, retrain, model_group_id, 
     ):
         """Train a model, cache it, and write metadata to a database
 
@@ -267,17 +291,27 @@ class ModelTrainer:
 
         unique_parameters = self.unique_parameters(parameters)
 
-        model_group_id = self.model_grouper.get_model_group_id(
-            class_path, unique_parameters, matrix_store.metadata, self.db_engine
-        )
+               
+        if retrain:
+            # if retrain, use the provided model_group_id
+            if not model_group_id:
+                raise ValueError("model_group_id should be provided when retrain") 
+            
+        else:
+            model_group_id = self.model_grouper.get_model_group_id(
+                class_path, unique_parameters, matrix_store.metadata, self.db_engine
+            )
+
+        # Writing th model to storage, then getting its size in kilobytes.
+        self.model_storage_engine.write(trained_model, model_hash)
+        
         logger.debug(
             f"Trained model: hash {model_hash}, model group {model_group_id} "
         )
-        # Writing th model to storage, then getting its size in kilobytes.
-        self.model_storage_engine.write(trained_model, model_hash)
+        logger.spam(f"Cached model: {model_hash}")
+ 
         model_size = sys.getsizeof(trained_model) / (1024.0)
 
-        logger.spam(f"Cached model: {model_hash}")
         model_id = self._write_model_to_db(
             class_path,
             unique_parameters,
@@ -287,9 +321,10 @@ class ModelTrainer:
             model_group_id,
             model_size,
             misc_db_parameters,
+            retrain,
         )
         logger.debug(f"Wrote model {model_id} [{model_hash}] to db")
-        return model_id
+        return model_id, model_hash 
 
     @contextmanager
     def cache_models(self):
@@ -347,7 +382,7 @@ class ModelTrainer:
         ]
 
     def process_train_task(
-        self, matrix_store, class_path, parameters, model_hash, misc_db_parameters, random_seed=None
+        self, matrix_store, class_path, parameters, model_hash, misc_db_parameters, random_seed=None, retrain=False, model_group_id=None, 
     ):
         """Trains and stores a model, or skips it and returns the existing id
 
@@ -384,8 +419,8 @@ class ModelTrainer:
                 f"(reason to train: {reason})"
             )
             try:
-                model_id = self._train_and_store_model(
-                    matrix_store, class_path, parameters, model_hash, misc_db_parameters, random_seed
+                model_id, model_hash = self._train_and_store_model(
+                    matrix_store, class_path, parameters, model_hash, misc_db_parameters, random_seed, retrain, model_group_id
                 )
             except BaselineFeatureNotInMatrix:
                 logger.warning(
@@ -405,6 +440,26 @@ class ModelTrainer:
     def flattened_grid_config(grid_config):
         return flatten_grid_config(grid_config)
 
+
+    def get_or_generate_random_seed(self, model_group_id, matrix_metadata, train_matrix_uuid):
+        """Look for an existing model with the same model group, train matrix metadata, and experiment-level
+           random seed and reuse this model's random seed if found, otherwise generate a new one. If multiple
+           matching models are found, we'll use the one with the most recent run time.
+
+           Args:
+                model_group_id (int): unique id for the model group this model is associated with
+                matrix_metadata (dict): metatdata associated with the model's training matrix
+                train_matrix_uuid (str): unique identifier for the model's training matrix
+        """
+        train_end_time = matrix_metadata["end_time"]
+        training_label_timespan = matrix_metadata["label_timespan"]
+        existing_seeds = retrieve_existing_model_random_seeds(self.db_engine, model_group_id, train_end_time, train_matrix_uuid, training_label_timespan, self.experiment_random_seed)
+        if existing_seeds:
+            return existing_seeds[0]
+        else:
+            return generate_python_random_seed()
+
+
     def generate_train_tasks(self, grid_config, misc_db_parameters, matrix_store=None):
         """Train and store configured models, yielding the ids one by one
 
@@ -432,7 +487,15 @@ class ModelTrainer:
         tasks = []
 
         for class_path, parameters in self.flattened_grid_config(grid_config):
-            random_seed = generate_python_random_seed()
+
+            unique_parameters = self.unique_parameters(parameters)
+            model_group_id = self.model_grouper.get_model_group_id(
+                class_path, unique_parameters, matrix_store.metadata, self.db_engine
+            )
+            random_seed = self.get_or_generate_random_seed(
+                model_group_id, matrix_store.metadata, matrix_store.uuid
+            )
+
             model_hash = self._model_hash(
                 matrix_store.metadata,
                 class_path,
