@@ -1,5 +1,7 @@
 import itertools
-import logging
+
+import verboselogs, logging
+logger = verboselogs.VerboseLogger(__name__)
 
 from triage.util.conf import convert_str_to_relativedelta, dt_from_str
 from triage.util.structs import AsOfTimeList
@@ -45,57 +47,80 @@ class Timechop:
         test_durations,
         test_label_timespans,
     ):
+
+        '''
+        Date strings should follow the format `YYYY-MM-DD`. Date intervals
+        should be strings of the Postgres interval input format.
+
+        This class is often used within the Triage experiment pipeline, and
+        initialized using parameters from a Triage [experiment config](../../../experiments/experiment-config/#time-splitting)
+
+        Arguments:
+            feature_start_time (str): Earliest date included in any feature
+            feature_end_time (str): Day after last feature date (all data
+                included in features are before this date)
+            label_start_time (str): Earliest date for which labels are available
+            label_end_time (str): Day AFTER last label date (all dates in any
+                model are before this date)
+            model_update_frequency (str): how frequently to retrain models
+            training_as_of_date_frequencies (str): time between rows for same
+                entity in train matrix
+            max_training_histories (str): Interval specifying how much history
+                for each entity to train on
+            training_label_timespans (str): how much time is included in a label
+                in the train matrix
+            test_as_of_date_frequencies (str): time between rows for same entity
+                in test matrix
+            test_durations (str): How long into the future to make predictions
+                for each entity. Controls the length of time included in a test
+                matrix
+            test_label_timespans (str): How much time is included in a label
+                in the test matrix.
+        '''
         self.feature_start_time = dt_from_str(
             feature_start_time
-        )  # earliest time included in any feature
+        )
         self.feature_end_time = dt_from_str(
             feature_end_time
-        )  # all data included in features are < this time
+        )
         if self.feature_start_time > self.feature_end_time:
             raise ValueError("Feature start time after feature end time.")
 
         self.label_start_time = dt_from_str(
             label_start_time
-        )  # earliest time included in any label
+        )
         self.label_end_time = dt_from_str(
             label_end_time
-        )  # all data in any label are < this time
+        )
         if self.label_start_time > self.label_end_time:
             raise ValueError("Label start time after label end time.")
 
-        # how frequently to retrain models
         self.model_update_frequency = convert_str_to_relativedelta(
             model_update_frequency
         )
 
-        # time between rows for same entity in train matrix
         self.training_as_of_date_frequencies = utils.convert_to_list(
             training_as_of_date_frequencies
         )
 
-        # time between rows for same entity in test matrix
         self.test_as_of_date_frequencies = utils.convert_to_list(
             test_as_of_date_frequencies
         )
 
-        # how much history for each entity to train on
         self.max_training_histories = utils.convert_to_list(max_training_histories)
 
-        # how long into the future to make predictions for each entity
         self.test_durations = utils.convert_to_list(test_durations)
 
-        # how much time is included in a label in the train matrix
         self.training_label_timespans = utils.convert_to_list(training_label_timespans)
 
-        # how much time is included in a label in the test matrix
         self.test_label_timespans = utils.convert_to_list(test_label_timespans)
 
     def chop_time(self):
         """ Given the attributes of the object, define all train/test splits
         for all combinations of the temporal parameters.
 
-        :return: a list of dictionaries defining train/test splits
-        :rtype: list
+        return:
+            list: a list of dictionaries defining train/test splits
         """
         matrix_set_definitions = []
         # in our example, we just have one value for each of these: 6month, 6month, and 3month
@@ -113,11 +138,9 @@ class Timechop:
             # will be every Oct. 1 from 2012 to 2016 (see comments in the method for details
             # on the calculation):
             # train_test_split_times = [2012-10-01, 2013-10-01, 2014-10-01, 2015-10-01, 2016-10-01]
-            logging.info(
-                "Calculating train/test split times for training prediction span {}, "
-                "test prediction span {}, test span {}".format(
-                    training_label_timespan, test_label_timespan, test_duration
-                )
+            logger.spam(
+                f"Calculating train/test split times for training prediction span {training_label_timespan}, "
+                f"test prediction span {test_label_timespan}, test span {test_duration}"
             )
             train_test_split_times = self.calculate_train_test_split_times(
                 training_label_timespan=convert_str_to_relativedelta(
@@ -126,7 +149,7 @@ class Timechop:
                 test_label_timespan=convert_str_to_relativedelta(test_label_timespan),
                 test_duration=test_duration,
             )
-            logging.info("Train/test split times: {}".format(train_test_split_times))
+            logger.spam(f"Train/test split times: {train_test_split_times}")
 
             # handle each training_as_of_date_frequency and max_training_history separately
             # to create matrices for each train_test_split_time.
@@ -137,18 +160,12 @@ class Timechop:
             ) in itertools.product(
                 self.training_as_of_date_frequencies, self.max_training_histories
             ):
-                logging.info(
-                    "Generating matrix definitions for training_as_of_date_frequency {}, "
-                    "max_training_history {}".format(
-                        training_as_of_date_frequency, max_training_history
-                    )
+                logger.spam(
+                    f"Generating matrix definitions for training_as_of_date_frequency {training_as_of_date_frequency}, "
+                    f"max_training_history {max_training_history}"
                 )
                 for train_test_split_time in train_test_split_times:
-                    logging.info(
-                        "Generating matrix definitions for split {}".format(
-                            train_test_split_time
-                        )
-                    )
+                    logger.spam(f"Generating matrix definitions for split {train_test_split_time}")
                     matrix_set_definitions.append(
                         self.generate_matrix_definitions(
                             train_test_split_time=train_test_split_time,
@@ -168,20 +185,18 @@ class Timechop:
         label spans in train matrices will end at this time, and this will be
         the first as of time in the respective test matrix.
 
-        :param training_label_timespan: how much time is included in training
-                                         labels
-        :type training_label_timespan: dateutil.relativedelta.relativedelta
-        :param test_label_timespan: how much time is included in test labels
-        :type test_label_timespan: dateutil.relativedelta.relativedelta
-        :param test_duration: for how long after the end of a training matrix are
-                          test predictions made
-        :type test_duration: str
+        Arguments:
+            training_label_timespan (dateutil.relativedelta.relativedelta): how much
+                time is included in training labels
+            test_label_timespan (dateutil.relativedelta.relativedelta): how much time is included in test labels
+            test_duration (str): for how long after the end of a training matrix are
+                test predictions made
 
-        :return: all split times for the temporal parameters
-        :rtype: list
-
-        :raises: ValueError if there are no valid split times in the temporal
-                 config
+        Returns:
+            list: all split times for the temporal parameters
+        Raises:
+            ValueError: if there are no valid split times in the temporal
+            config
         """
 
         # we always want to be sure we're using the most recent data, so for the splits,
@@ -198,18 +213,14 @@ class Timechop:
             raise ValueError(
                 "Final test label date cannot be after end of feature time."
             )
-        logging.info("Final label as of date: {}".format(last_test_label_time))
+        logger.spam(f"Final label as of date: {last_test_label_time}")
 
         # all split times have to allow at least one training label before them
         # e.g., earliest_possible_split_time = max(1995-01-01, 2012-01-01) + 6month = 2012-01-01
         earliest_possible_split_time = training_label_timespan + max(
             self.feature_start_time, self.label_start_time
         )
-        logging.info(
-            "Earliest possible train/test split time: {}".format(
-                earliest_possible_split_time
-            )
-        )
+        logger.spam(f"Earliest possible train/test split time: {earliest_possible_split_time}")
 
         # last split is the first as of time in the final test matrix
         # that is, starting from the label_end_time, we've walked back by the test_label_timespan
@@ -219,7 +230,7 @@ class Timechop:
         # e.g., last_split_time = 2017-01-01 - 3month = 2016-10-01
         test_delta = convert_str_to_relativedelta(test_duration)
         last_split_time = last_test_label_time - test_delta
-        logging.info("Final split time: {}".format(last_split_time))
+        logger.spam(f"Final split time: {last_split_time}")
         if last_split_time < earliest_possible_split_time:
             raise ValueError("No valid train/test split times in temporal config.")
 
@@ -246,21 +257,19 @@ class Timechop:
         """ Given a start and stop time, a frequncy, and a direction, calculate the
         as of times for a matrix.
 
-        :param as_of_start_limit: the earliest possible as of time for a matrix
-        :param as_of_end_limit: the last possible as of time for the matrix
-        :param data_frequency: how much time between rows for a single entity
-        :param forward: whether to generate times forward from the start time
-                        (True) or backward from the end time (False)
+        Arguments:
+            as_of_start_limit (datetime.datetime): the earliest possible as of time for a matrix
+            as_of_end_limit (datetime.datetime): the last possible as of time for the matrix
+            data_frequency (str): The time interval that should pass between rows
+                of a single entity. Of the format `'date unit'`. For example,
+                `'1 month'`.
+            forward (boolean): whether to generate times forward from the start time
+                            (True) or backward from the end time (False)
 
-        :return: list of as of times for the matrix
-        :rtype: list
+        return:
+            list: list of as of times for the matrix
         """
-        logging.info(
-            "Calculating as_of_times from %s to %s using example frequency %s",
-            as_of_start_limit,
-            as_of_end_limit,
-            data_frequency,
-        )
+        logger.spam(f"Calculating as_of_times from {as_of_start_limit} to {as_of_end_limit} using example frequency {data_frequency}")
 
         as_of_times = []
 
@@ -309,23 +318,18 @@ class Timechop:
         """ Given a split time and parameters for train and test matrices,
         generate as of times and metadata for the matrices in the split.
 
-        :param train_test_split_time: the limit of the last label in the matrix
-        :type train_test_split_time: datetime.datetime
-        :param training_as_of_date_frequency: how much time between rows for an entity
-                                        in a training matrix
-        :type training_as_of_date_frequency: str
-        :param max_training_history: how far back from split do train
-                                    as_of_times go
-        :type max_training_history: str
-        :param test_duration: how far forward from split do test as_of_times go
-        :type test_duration: str
-        :param training_label_timespan: how much time covered by train labels
-        :type training_label_timespan: str
-        :param test_label_timespan: how much time is covered by test labels
-        :type test_label_timespan: str
+        Arguments:
+            train_test_split_time (datetime.datetime): the limit of the last label in the matrix
+            training_as_of_date_frequency (str): how much time between rows for an entity
+                                            in a training matrix
+            max_training_history (str): how far back from split do train
+                                        as_of_times go
+            test_duration (str): how far forward from split do test as_of_times go
+            training_label_timespan (str): how much time covered by train labels
+            test_label_timespan (str): how much time is covered by test labels
 
-        :return: dictionary defining the train and test matrices for a split
-        :rtype: dict
+        returns:
+            dict: dictionary defining the train and test matrices for a split
         """
 
         # continuing our example, let's consider the case when this is called for the last
@@ -367,11 +371,7 @@ class Timechop:
             "train_matrix": train_matrix_definition,
             "test_matrices": test_matrix_definitions,
         }
-        logging.info(
-            "Matrix definitions for train/test split %s: %s",
-            train_test_split_time,
-            matrix_set_definition
-        )
+        logger.spam(f"Matrix definitions for train/test split {train_test_split_time}: {matrix_set_definition}")
 
         return matrix_set_definition
 
@@ -385,20 +385,17 @@ class Timechop:
         """ Given a split time and the parameters of a training matrix, generate
         the as of times and metadata for a train matrix.
 
-        :param train_test_split_time: the limit of the last label in the matrix
-        :type train_test_split_time: datetime.datetime
-        :param training_label_timespan: how much time is covered by the labels
-        :type training_label_timespan: str
-        :param max_training_history: how far back from split do as_of_times go
-        :type max_training_history: str
-        :param training_as_of_date_frequency: how much time between rows for an entity
-        :type training_as_of_date_frequency: str
+        Arguments:
+            train_test_split_time (datetime.datetime): the limit of the last label in the matrix
+            training_label_timespan (str): how much time is covered by the labels
+            max_training_history (str): how far back from split do as_of_times go
+            training_as_of_date_frequency (str): how much time between rows for an entity
 
-        :return: dictionary containing the temporal parameters and as of times
-                 for a train matrix
-        :rtype: dict
+        return:
+            dict: dictionary containing the temporal parameters and as of times
+                  for a train matrix
         """
-
+        logger.debug(f"Generating train matrix definitions for trin/test split {train_test_split_time}")
         # for our example, this will be called with:
         #   train_test_split_time = 2016-10-01
         #   training_label_timespan = 6month
@@ -429,10 +426,7 @@ class Timechop:
         )
         if earliest_possible_train_as_of_time < experiment_as_of_time_limit:
             earliest_possible_train_as_of_time = experiment_as_of_time_limit
-        logging.info(
-            "earliest possible train as of time: %s",
-            earliest_possible_train_as_of_time
-        )
+        logger.spam(f"Earliest possible train as of time: {earliest_possible_train_as_of_time}")
 
         # with the last as of time and the earliest possible time known,
         # calculate all the as of times for the matrix, stepping backwards
@@ -447,7 +441,7 @@ class Timechop:
             as_of_end_limit=last_train_as_of_time,
             data_frequency=convert_str_to_relativedelta(training_as_of_date_frequency),
         )
-        logging.info("train as of times: %s", train_as_of_times)
+        logger.spam(f"Train as of times: {train_as_of_times}")
 
         # create a dict of the matrix metadata
         matrix_definition = {
@@ -468,15 +462,13 @@ class Timechop:
         """ Given a train/test split time and a set of testing parameters,
         generate the metadata and as of times for the test matrices in a split.
 
-        :param train_test_split_time: the limit of the last label in the matrix
-        :type train_test_split_time: datetime.datetime
-        :param test_duration: how far forward from split do test as_of_times go
-        :type test_duration: str
-        :param test_label_timespan: how much time is covered by test labels
-        :type test_label_timespan: str
+        Arguments:
+            train_test_split_time (datetime.datetime): the limit of the last label in the matrix
+            test_duration (str): how far forward from split do test as_of_times go
+            test_label_timespan (str): how much time is covered by test labels
 
-        :return: list of dictionaries defining the test matrices for a split
-        :rtype: list
+        return:
+            list: list of dictionaries defining the test matrices for a split
         """
 
         # for our example, this will be called with:
@@ -491,22 +483,16 @@ class Timechop:
         #
         # for the example, as_of_time_limit = 2016-10-01 + 3month = 2017-01-01
         # (note as well that this will be treated as an _exclusive_ limit)
-        logging.info(
-            "Generating test matrix definitions for train/test split %s",
-            train_test_split_time
-        )
+        logger.debug(f"Generating test matrix definitions for train/test split {train_test_split_time}")
         test_definitions = []
         test_delta = convert_str_to_relativedelta(test_duration)
         as_of_time_limit = train_test_split_time + test_delta
-        logging.info("All test as of times before %s", as_of_time_limit)
+        logger.spam("All test as of times before %s", as_of_time_limit)
 
         # calculate the as_of_times associated with each test data frequency
         # for our example, we just have one, 1month
         for test_as_of_date_frequency in self.test_as_of_date_frequencies:
-            logging.info(
-                "Generating test matrix definitions for test data frequency %s",
-                test_as_of_date_frequency
-            )
+            logger.spam(f"Generating test matrix definitions for test data frequency {test_as_of_date_frequency}")
 
             # for test as_of_times we step _forwards_ from the train_test_split_time
             # to ensure that we always have a prediction set made immediately after
@@ -525,7 +511,7 @@ class Timechop:
                 data_frequency=convert_str_to_relativedelta(test_as_of_date_frequency),
                 forward=True,
             )
-            logging.info("test as of times: %s", test_as_of_times)
+            logger.spam(f"test as of times: {test_as_of_times}")
             test_definition = {
                 "first_as_of_time": train_test_split_time,
                 "last_as_of_time": max(test_as_of_times),
