@@ -1,6 +1,7 @@
 import importlib
 
 import verboselogs, logging
+
 logger = verboselogs.VerboseLogger(__name__)
 
 from itertools import permutations
@@ -13,14 +14,15 @@ from triage.component import architect
 from triage.component import catwalk
 from triage.component.timechop import Timechop
 
-from triage.util.conf import convert_str_to_relativedelta
+from triage.util.conf import convert_str_to_relativedelta, load_query_if_needed
 from triage.validation_primitives import string_is_tablesafe
 
 
 class Validator:
-    def __init__(self, db_engine=None, strict=True):
+    def __init__(self, db_engine=None, strict=True, entity_id_column="entity_id"):
         self.db_engine = db_engine
         self.strict = strict
+        self.entity_id_column = entity_id_column
 
     def run(self, *args, **kwargs):
         try:
@@ -38,6 +40,7 @@ class Validator:
 class TemporalValidator(Validator):
     def _run(self, temporal_config):
         logger.spam("Validating temporal configuration")
+
         def dt_from_str(dt_str):
             return datetime.strptime(dt_str, "%Y-%m-%d")
 
@@ -130,16 +133,15 @@ class TemporalValidator(Validator):
                         )
                     )
 
-
         logger.debug("Validation of temporal configuration was successful")
 
+
 class FeatureAggregationsValidator(Validator):
     def _validate_keys(self, aggregation_config):
         logger.spam("Validating feature aggregation keys")
         for key in [
             "from_obj",
             "intervals",
-            "groups",
             "knowledge_date_column",
             "prefix",
         ]:
@@ -153,18 +155,36 @@ class FeatureAggregationsValidator(Validator):
                         )
                     )
                 )
-                if not string_is_tablesafe(aggregation_config['prefix']):
-                    raise ValueError(
-                        dedent(
-                            f"""Section: feature_aggregations -
-                            Feature aggregation prefix should only contain
-                            lowercase letters, numbers, and underscores.
-                            Aggregation config: {aggregation_config}
-                            """
-                        )
+        if not string_is_tablesafe(aggregation_config["prefix"]):
+            raise ValueError(
+                dedent(
+                    f"""Section: feature_aggregations -
+                    Feature aggregation prefix should only contain
+                    lowercase letters, numbers, and underscores.
+                    Aggregation config: {aggregation_config}
+                    """
+                )
+            )
+        if "groups" in aggregation_config:
+            if aggregation_config["groups"] != [self.entity_id_column]:
+                raise ValueError(
+                    dedent(
+                        """Specifying groupings for feature aggregation is 
+                        not supported. Features can only be grouped at the 
+                        entity_id level."""
                     )
+                )
+            else:
+                logger.warning(
+                    dedent(
+                        """Specifying groupings for feature aggregation is 
+                        not supported. In the future, please exclude this key 
+                        from your feature configuration."""
+                    )
+                )
 
         logger.debug("Validation of feature aggregation keys was successful")
+
     def _validate_aggregates(self, aggregation_config):
         logger.spam("Validating aggregates")
         if (
@@ -230,6 +250,7 @@ class FeatureAggregationsValidator(Validator):
                     )
 
         logger.debug("Validation of categoricals was successful")
+
     def _validate_from_obj(self, from_obj):
         conn = self.db_engine.connect()
         logger.spam("Validating from_obj")
@@ -272,21 +293,6 @@ class FeatureAggregationsValidator(Validator):
                         )
                     )
 
-    def _validate_groups(self, groups):
-        logger.spam("Validating groups")
-        if "entity_id" not in groups:
-            raise ValueError(
-                dedent(
-                    """
-            Section: feature_aggregations -
-            List of groups needs to include 'entity_id'.
-            Passed list: {}""".format(
-                        groups
-                    )
-                )
-            )
-        logger.debug("Validation of groups was successful")
-
     def _validate_imputation_rule(self, aggregate_type, impute_rule):
         """Validate the imputation rule for a given aggregation type."""
         logger.spam("Validating imputation rule")
@@ -354,19 +360,19 @@ class FeatureAggregationsValidator(Validator):
         agg_types = ["aggregates", "categoricals", "array_categoricals"]
 
         for agg_type in agg_types:
-            logger.spam('Validating imputation rules for aggregation type %s', agg_type)
+            logger.spam("Validating imputation rules for aggregation type %s", agg_type)
             # base_imp are the top-level rules, `such as aggregates_imputation`
             base_imp = aggregation_config.get(agg_type + "_imputation", {})
 
             # loop through the individual aggregates
             for agg in aggregation_config.get(agg_type, []):
-                logger.spam('Validating imputation rules for aggregation %s', agg)
+                logger.spam("Validating imputation rules for aggregation %s", agg)
                 # combine any aggregate-level imputation rules with top-level ones
                 imp_dict = dict(base_imp, **agg.get("imputation", {}))
 
                 # imputation rules are metric-specific, so check each metric's rule
                 for metric in agg["metrics"]:
-                    logger.spam('Validating imputation rules for metric: %s', metric)
+                    logger.spam("Validating imputation rules for metric: %s", metric)
                     # metric rules may be defined by the metric name (e.g., 'max')
                     # or with the 'all' catch-all, with named metrics taking
                     # precedence. If we fall back to {}, the rule validator will
@@ -382,7 +388,6 @@ class FeatureAggregationsValidator(Validator):
         self._validate_categoricals(aggregation_config.get("categoricals", []))
         self._validate_from_obj(aggregation_config["from_obj"])
         self._validate_time_intervals(aggregation_config["intervals"])
-        self._validate_groups(aggregation_config["groups"])
         self._validate_imputations(aggregation_config)
         logger.debug("Validation of aggregation config was successful")
 
@@ -479,17 +484,22 @@ class LabelConfigValidator(Validator):
                 )
             )
 
-        if "query" not in label_config:
+        if len(set(label_config.keys()).intersection({"query", "filepath"})) != 1:
             raise ValueError(
                 dedent(
                     """
             Section: label_config -
-            key 'query' not found. You must define a label query."""
+            keys ({label_config.keys()}) do not contain exactly one of 'filepath'
+            or 'query'. You must pass a filepath to a label query or include one
+            in the config."""
                 )
             )
-        if 'name' in label_config and not string_is_tablesafe(label_config['name']):
-            raise ValueError("Section: label_config - "
-                             "name should only contain lowercase letters, numbers, and underscores")
+        label_config = load_query_if_needed(label_config)
+        if "name" in label_config and not string_is_tablesafe(label_config["name"]):
+            raise ValueError(
+                "Section: label_config - "
+                "name should only contain lowercase letters, numbers, and underscores"
+            )
         self._validate_query(label_config["query"])
         self._validate_include_missing_labels_in_train_as(
             label_config.get("include_missing_labels_in_train_as", None)
@@ -500,14 +510,20 @@ class LabelConfigValidator(Validator):
 class CohortConfigValidator(Validator):
     def _run(self, cohort_config):
         logger.spam("Validating of cohort configuration")
-        if "query" not in cohort_config:
+        if not cohort_config:
+            logger.debug("No cohort config specified, label config will be used instead")
+            return
+        if len(set(cohort_config.keys()).intersection({"query", "filepath"})) != 1:
             raise ValueError(
                 dedent(
                     """
             Section: cohort_config -
-            key 'query' not found. You must define a cohort query."""
+            keys ({cohort_config.keys()}) do not contain exactly one of 'filepath'
+            or 'query'. You must pass a filepath to a cohort query or include one
+            in the config."""
                 )
             )
+        cohort_config = load_query_if_needed(cohort_config)
         query = cohort_config["query"]
         if "{as_of_date}" not in query:
             raise ValueError(
@@ -518,9 +534,11 @@ class CohortConfigValidator(Validator):
             {as_of_date} must be present"""
                 )
             )
-        if 'name' in cohort_config and not string_is_tablesafe(cohort_config['name']):
-            raise ValueError("Section: cohort_config - "
-                             "name should only contain lowercase letters, numbers, and underscores")
+        if "name" in cohort_config and not string_is_tablesafe(cohort_config["name"]):
+            raise ValueError(
+                "Section: cohort_config - "
+                "name should only contain lowercase letters, numbers, and underscores"
+            )
         dated_query = query.replace("{as_of_date}", "2016-01-01")
         logger.spam("Validating cohort query via SQL EXPLAIN")
         try:
@@ -695,7 +713,7 @@ class ModelGroupKeysValidator(Validator):
                 )
             )
         classifier_keys = ["class_path", "parameters"]
-        # planner_keys are defined in architect.Planner._make_metadata
+        # planner_keys are defined in architect.Planner.make_metadata
         planner_keys = [
             "feature_start_time",
             "end_time",
@@ -799,7 +817,10 @@ class PredictionConfigValidator(Validator):
         logger.spam("Validating prediction configuration")
         rank_tiebreaker = prediction_config.get("rank_tiebreaker", None)
         # the tiebreaker is optional, so only try and validate if it's there
-        if rank_tiebreaker and rank_tiebreaker not in catwalk.utils.AVAILABLE_TIEBREAKERS:
+        if (
+            rank_tiebreaker
+            and rank_tiebreaker not in catwalk.utils.AVAILABLE_TIEBREAKERS
+        ):
             raise ValueError(
                 "Section: prediction - "
                 f"given tiebreaker must be in {catwalk.utils.AVAILABLE_TIEBREAKERS}"
@@ -879,7 +900,7 @@ class ScoringConfigValidator(Validator):
                                 """
                             )
                         )
-                    if not string_is_tablesafe(subset['name']):
+                    if not string_is_tablesafe(subset["name"]):
                         raise ValueError(
                             dedent(
                                 f"""Section: subsets -
@@ -908,16 +929,19 @@ class ScoringConfigValidator(Validator):
                             )
                         )
 
-
         logger.debug("Validation of scoring configuration was successful")
 
+
 class BiasAuditConfigValidator(Validator):
     def _run(self, bias_audit_config):
         logger.spam("Validating bias audit configuration")
         if not bias_audit_config:
             # if empty, that's fine, shortcut out
             return
-        if 'from_obj_query' in bias_audit_config and 'from_obj_table' in bias_audit_config:
+        if (
+            "from_obj_query" in bias_audit_config
+            and "from_obj_table" in bias_audit_config
+        ):
             raise ValueError(
                 dedent(
                     """
@@ -926,7 +950,10 @@ class BiasAuditConfigValidator(Validator):
                     Please only specify one."""
                 )
             )
-        if 'from_obj_query' not in bias_audit_config and 'from_obj_table' not in bias_audit_config:
+        if (
+            "from_obj_query" not in bias_audit_config
+            and "from_obj_table" not in bias_audit_config
+        ):
             raise ValueError(
                 dedent(
                     """
@@ -936,10 +963,10 @@ class BiasAuditConfigValidator(Validator):
                 )
             )
         for key in [
-                "attribute_columns",
-                "knowledge_date_column",
-                "entity_id_column",
-                "ref_groups_method",
+            "attribute_columns",
+            "knowledge_date_column",
+            "entity_id_column",
+            "ref_groups_method",
         ]:
             if key not in bias_audit_config:
                 raise ValueError(
@@ -947,11 +974,16 @@ class BiasAuditConfigValidator(Validator):
                         f"""Section: bias_audit_config - '{key} required as key: bias_audit_config config: {bias_audit_config}"""
                     )
                 )
-        percentile_thresholds = bias_audit_config.get('thresholds', {}).get('percentiles', [])
+        percentile_thresholds = bias_audit_config.get("thresholds", {}).get(
+            "percentiles", []
+        )
         if any(threshold < 0 or threshold > 100 for threshold in percentile_thresholds):
-            raise ValueError("Section: bias_audit_config - All percentile thresholds must be between 0 and 100")
+            raise ValueError(
+                "Section: bias_audit_config - All percentile thresholds must be between 0 and 100"
+            )
         logger.debug("Validation of bias audit configuration was successful")
 
+
 class ExperimentValidator(Validator):
     def run(self, experiment_config):
         logger.spam("Validating experiment configuration")
@@ -997,4 +1029,6 @@ class ExperimentValidator(Validator):
         if self.strict:
             logger.success("Experiment validation ran to completion with no errors")
         else:
-            logger.warning("Experiment validation complete. All configuration problems have been displayed as warnings")
+            logger.warning(
+                "Experiment validation complete. All configuration problems have been displayed as warnings"
+            )
